@@ -338,9 +338,14 @@ static ssize_t operate_cipher(int sk, __u32 operation,
 
 		iov[0].iov_base = (void *) ad;
 		iov[0].iov_len = ad_len;
-		iov[1].iov_base = (void *) in;
-		iov[1].iov_len = in_len;
-		msg.msg_iovlen = 2;
+
+		msg.msg_iovlen = 1;
+
+		if (in) {
+			iov[1].iov_base = (void *) in;
+			iov[1].iov_len = in_len;
+			msg.msg_iovlen = 2;
+		}
 	} else {
 		iov[0].iov_base = (void *) in;
 		iov[0].iov_len = in_len;
@@ -607,7 +612,10 @@ LIB_EXPORT bool l_aead_cipher_encrypt(struct l_aead_cipher *cipher,
 	if (unlikely(!cipher))
 		return false;
 
-	if (unlikely(!in) || unlikely(!out))
+	if (unlikely(!in && !ad) || unlikely(!out))
+		return false;
+
+	if (unlikely(!in && in_len) || unlikely(!ad && ad_len))
 		return false;
 
 	if (cipher->type == L_AEAD_CIPHER_AES_CCM) {
@@ -677,6 +685,10 @@ static void init_supported()
 
 	initialized = true;
 
+	for (c = 0; c < L_ARRAY_SIZE(local_impl_ciphers); c++)
+		if (HAVE_LOCAL_IMPLEMENTATION(c))
+			supported_ciphers |= 1 << c;
+
 	sk = socket(PF_ALG, SOCK_SEQPACKET | SOCK_CLOEXEC, 0);
 	if (sk < 0)
 		return;
@@ -698,10 +710,6 @@ static void init_supported()
 		supported_ciphers |= 1 << c;
 	}
 
-	for (c = 0; c < L_ARRAY_SIZE(local_impl_ciphers); c++)
-		if (HAVE_LOCAL_IMPLEMENTATION(c))
-			supported_ciphers |= 1 << c;
-
 	strcpy((char *) salg.salg_type, "aead");
 
 	for (a = L_AEAD_CIPHER_AES_CCM; a <= L_AEAD_CIPHER_AES_GCM; a++) {
